@@ -1467,7 +1467,7 @@ class SQLCli(object):
         if matchObj:
             m_filetype = str(matchObj.group(1)).strip()
             m_filename = str(matchObj.group(2)).strip().replace('\r', '').replace('\n', '')
-            m_formula_str = str(matchObj.group(3).replace('\r', '').replace('\n', '').strip())
+            m_formula_str = str(matchObj.group(3).strip())
             m_rows = 1
             Create_file(p_filetype=m_filetype,
                         p_filename=m_filename,
@@ -1787,7 +1787,7 @@ class SQLCli(object):
 
         # 开始依次处理SQL语句
         try:
-            # 如果用户制定了用户名，口令，尝试直接进行数据库连接
+            # 如果用户指定了用户名，口令，尝试直接进行数据库连接
             if self.logon:
                 if not self.DoSQL("connect " + str(self.logon)):
                     m_runCli_Result = False
